@@ -5,11 +5,13 @@ import torch
 
 class CrossEntropyLoss(torch.nn.Module):
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
-        self.criterion  = torch.nn.CrossEntropyLoss(ignore_index=0)
+        self.criterion = torch.nn.CrossEntropyLoss(ignore_index=0)
 
-    def forward(self, pred: torch.tensor, batch: Dict[str, torch.tensor]) -> torch.tensor:
+    def forward(self,
+                pred: torch.tensor,
+                batch: Dict[str, torch.tensor]) -> torch.tensor:
         phonemes = batch['phonemes']
         loss = self.criterion(pred.transpose(1, 2), phonemes[:, 1:])
         return loss
@@ -21,7 +23,9 @@ class CTCLoss(torch.nn.Module):
         super().__init__()
         self.criterion  = torch.nn.CTCLoss()
 
-    def forward(self, pred: torch.tensor, batch: Dict[str, torch.tensor]) -> torch.tensor:
+    def forward(self,
+                pred: torch.tensor,
+                batch: Dict[str, torch.tensor]) -> torch.tensor:
         pred = pred.transpose(0, 1).log_softmax(2)
         phonemes = batch['phonemes']
         text_len = batch['text_len']
